#!/bin/tcsh

set region = "-R-106.93451/-106.90916/34.06863/34.08084"
#set boundaries = "-BSWnea0.005f.1m/0.0025f.05m"
set boundaries = "-BSWne -Bxa0.005f.1m -Bya0.0025f0.05m"
set projection = "-JM9.5i"
set misc = "-K -V -X1i -Y1.5i"
set post_script_name = station_map.ps

gmt psbasemap $region $projection $boundaries $misc > $post_script_name

#gmt surface PIC.xyz -GPIC.grd $region -I.0001/.0001
#set misc = "-D -Z -Chaxby"
#gmt grd2cpt PIC.grd $misc > PIC.cpt

#set misc = "-A0 -Nt"
#gmt grdgradient PIC.grd -GPIC.grad $misc

set misc = "-O -CPIC.cpt -V -IPIC.grad -K"
gmt grdimage PIC.grd -R -J $misc >> $post_script_name

set misc = "-C10 -A20+g255+o+p+u"m" -O -K -V"
gmt grdcontour PIC.grd -R -J $misc >> $post_script_name

set misc = "-O -K -Sa0.2i -W1p/0 -G0"
gmt psxy -R -J $misc << END >> $post_script_name
-106.91911 34.07344
END

set misc = "-O -K -Sa0.2i -W1p/0 -G0/0/255"
gmt psxy -R -J $misc << END >> $post_script_name
-106.92027 34.073959
-106.92382 34.076003
-106.91941 34.075728
END

set misc = "-O -F+f12p,Helvetica,white -G0 -K"
gmt pstext -R -J $misc << END >> $post_script_name
-106.91911 34.07294 PIC
END

set misc = "-D4.5i/-0.5i/9i/0.25ih -O -K -B10/:meters:"
gmt psscale -CPIC.cpt $misc >> $post_script_name

set region_inset = "-R-130/-70/26/50"
set projection_inset = "-JM3i"
set misc = "-O -K -Bnsew+g255 --MAP_FRAME_TYPE=inside"
gmt psbasemap $region_inset $projection_inset $misc >> $post_script_name

set misc = "-O -K -Sa0.2 -W1p/0 -G0"
gmt psxy -R -J $misc << END >> $post_script_name
-106.903 34.0663
END

set misc = "-Dl -Na -W.25p/0 -O -K -A5000"
gmt pscoast -R -J $misc >> $post_script_name

set sac_data = IIPC.PC.LHZ.SAC
set misc = "-O -K -Bnews+g255 -Y6i"
set projection_sac_data = "-JX9.5i/.7i"
set region_sac_data = `./sac2stdout/sac2stdout $sac_data | gmt gmtinfo -I1`
gmt psbasemap $region_sac_data $projection_sac_data $misc >> $post_script_name

set limits = `./sac2stdout/sac2stdout $sac_data | gmt gmtinfo -C`
set xtick = `echo $limits | awk '{print ($2-$1)/20}'`
set ytick = `echo $limits | awk '{print ($4-$3)/5}'`
set misc = "-O -W1p,20/120/200 -Bxa${xtick}f${xtick}g${xtick} -Bya${ytick}f${ytick}g${ytick} -BnSeW"
./sac2stdout/sac2stdout $sac_data | gmt psxy -R -J $misc >> $post_script_name

set png_name = station_map.png
gmt psconvert $post_script_name -Tg
echo "$post_script_name created and converted to $png_name"

exit
