/*
sacc_2_stdout.c
program reads in a sac file and returns the following values:
time amplitude
time amplitude
time amplitude
  .     .
  .     .
  .     .
*/

//standard headers
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>
#ifdef HAVE_MALLOC_H
#include <malloc.h>
#endif

//user header
#include "mysac64.h"

//define maximum number of points in a sac file
#define NPTS_SAC_FILE_MAX 200000

//function prototypes
//read_sac_d
extern SAC_HD *read_sac_d(char *, double *, SAC_HD *, long);


/*-----------------MAIN----------------------*/
int main(int argc, char *argv[]) {
	/* local variables */
	int i;
	char sac_file_name[100];
	double *signal;
	SAC_HD sac_header;

	/* check usage */
	if (argc != 2) {
		fprintf(stderr,"Usage: %s sac_file\n",argv[0]);
		fprintf(stderr,"%s outputs the data from a sac file to standard out:\n",argv[0]);
		exit(1);
	}

	/* allocate memory */
	signal = malloc(sizeof(signal) * NPTS_SAC_FILE_MAX);

	/* copy the arguments */
	strcpy(sac_file_name,argv[1]);

	/* read sac file */
	if (!read_sac_d(sac_file_name,signal,&(sac_header),NPTS_SAC_FILE_MAX)) {
		fprintf(stderr,"Error: could not open %s with read_sac\n", sac_file_name);
		exit(2);
	}

	/* print out the time and amplitude */
	for (i=0; i<sac_header.npts; i++) {
		printf("%f %3.8g\n", i * sac_header.delta+sac_header.b, signal[i]);
	}

	/* free memory */
	free(signal);	
	
	return 0;
}



